```
Usage: vcd gateway configure-ip-settings [OPTIONS] <gateway name>

Options:
  -e, --external-network <external network>
                                  external networks to which the new gateway
                                  can connect.  [required]
  -s, --subnet-available <subnet> <enable> <ip>
                                  set the subnet settings  [required]
  -h, --help                      Show this message and exit.

```
